netapp_ontap.models.cluster_nodes_ha_giveback_status API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.cluster_nodes_ha_giveback_status`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ClusterNodesHaGivebackStatusSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ClusterNodesHaGivebackStatus object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `aggregate: Aggregate GET POST PATCH`

    The aggregate field of the cluster_nodes_ha_giveback_status.

  `error: ClusterNodesHaGivebackStatusError GET POST PATCH`

    Indicates the failed aggregate giveback code and message.

  `state: str GET POST PATCH`

    Giveback state of the aggregate.
    Possible values include no aggregates to giveback(nothing_to_giveback), failed to disable background disk firmware update(BDFU) on source node(failed_bdfu_source),
    giveback delayed as disk firmware update is in progress on source node(delayed_bdfu_source), performing veto checks(running_checks).

    Valid choices:

    - done
    - failed
    - in_progress
    - not_started
    - nothing_to_giveback
    - failed_bdfu_source
    - failed_bdfu_dest
    - delayed_bdfu_source
    - delayed_bdfu_dest
    - running_checks